@@ -3,11 +3,16 @@ package Data::Chronicle::Reader;
 use 5.014;
 use strict;
 use warnings;
+use Data::Chronicle;
 
 =head1 NAME
 
 Data::Chronicle::Reader - Provides reading from an efficient data storage for volatile and time-based data
 
+=cut
+
+our $VERSION = $Data::Chronicle::VERSION;
+
 =head1 DESCRIPTION
 
 This module contains helper methods which can be used to store and retrieve information
